# My Distribution Package

My Distribution Package is a Python package that provides functionality for Gaussian and Binomial distributions.

## Installation

You can install the package using `pip`:
## Usage

### Gaussian Distribution

```python
from gnd_distributions import Gaussian```
### Binomial Distribution
```from gnd_distributions import Binomial```
